@@ -1,7 +1,7 @@
 %%%-------------------------------------------------------------------
 %%% Created : 26 Sep 2018 by Evgeny Khramtsov <ekhramtsov@process-one.net>
 %%%
-%%% Copyright (C) 2002-2020 ProcessOne, SARL. All Rights Reserved.
+%%% Copyright (C) 2002-2021 ProcessOne, SARL. All Rights Reserved.
 %%%
 %%% Licensed under the Apache License, Version 2.0 (the "License");
 %%% you may not use this file except in compliance with the License.
@@ -501,26 +501,6 @@ bad_url_host_test() ->
        {bad_url, empty_host, <<"http:///path">>},
        yconf:parse(File, #{a => yconf:url()})).
 
-bad_url_no_default_port_test() ->
-    File = file(["a: foo://domain.tld"]),
-    ?checkError(
-       {bad_url, {no_default_port, foo, _}, _},
-       yconf:parse(File, #{a => yconf:url([])})).
-
-bad_url_bad_port_test() ->
-    File = file(["a: http://domain.tld:0"]),
-    ?checkError(
-       {bad_url, bad_port, _},
-       yconf:parse(File, #{a => yconf:url([])})),
-    File = file(["a: http://domain.tld:-1"]),
-    ?checkError(
-       {bad_url, bad_port, _},
-       yconf:parse(File, #{a => yconf:url([])})),
-    File = file(["a: http://domain.tld:65536"]),
-    ?checkError(
-       {bad_url, bad_port, _},
-       yconf:parse(File, #{a => yconf:url([])})).
-
 bad_url_test() ->
     File = file(["a: bad"]),
     ?checkError(
